# Welcome to cads_toolbox's documentation!

CADS Toolbox library provides an entry point to the CADS data and software.

```{toctree}
:caption: 'Contents:'
:maxdepth: 2

API Reference <_api/cads_toolbox/index>
```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
